# hpo-toolkit
A toolkit for working with Human Phenotype Ontology in Python

TODO - add description

## Install

HPO toolkit is available from PyPi:

```shell
pip install hpo-toolkit
```

## Run tests

We use `tox` to run tests.
 
```shell
pip install -U tox
tox run
```
